/*
  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0
import QtPositioning 5.2


Page {
    id: page

    property string time:"Future"
    property string sorting:"Relevance"
    property int range:30
    property int number:30

    function getName(coords) {
        var doc = new XMLHttpRequest();
        var res;
        doc.open('GET', 'http://maps.googleapis.com/maps/api/geocode/xml?latlng='+ coords +'&sensor=true');
        doc.onreadystatechange = function () {
            if (doc.readyState === XMLHttpRequest.DONE) {
                if (doc.status === 200) {
                    var root = doc.responseXML.documentElement;
                    if (root) {
                        city.text=root.childNodes[3].childNodes[3].childNodes[0].nodeValue;
                        //return root.childNodes[3].childNodes[3].childNodes[0].nodeValue;
                    } else {
                        res="Unable to get location"
                    }
                } else {
                    res="Unable to get location"
                }
            }
        }
        doc.send();
    }

    // To enable PullDownMenu, place our content in a SilicaFlickable
    SilicaFlickable {
        id: container
        anchors.fill: parent
        contentHeight: column.height

        // PullDownMenu and PushUpMenu must be declared in SilicaFlickable, SilicaListView or SilicaGridView
        PullDownMenu {
            MenuItem {
                text: "Options"
                onClicked: pageStack.push(optionsPage)
            }
        }


        PositionSource {
            id: positionSource
            active: true
            updateInterval: 10
        }

        Column {

            id: column
            width: page.width
            spacing: Theme.paddingLarge

            PageHeader {
                title: "StarEvents"
            }

            Row {

                TextArea    {
                    horizontalAlignment: TextInput.AlignHCenter
                    id: city
                    width: 480
                    height: text.height
                    placeholderText: "Enter a location!"
                    label: "Location"
                }

                IconButton  {
                    width: 10
                    height: 10
                    icon.source: "http://s24.postimg.org/j2se4iv1t/gps.png"
                    onClicked:{
                        positionSource.start();
                        positionSource.update();

                        if (!isNaN(positionSource.position.coordinate.latitude) &&
                                !isNaN(positionSource.position.coordinate.longitude))
                        {
                            getName(positionSource.position.coordinate.latitude+","+positionSource.position.coordinate.longitude);
                        } else
                        {
                            city.text="Unable retrieve location"
                        }


                    }
                }
            }

            TextField    {
                horizontalAlignment: TextInput.AlignHCenter
                id: key
                width: 480
                height: text.height
                placeholderText: "Enter a keyword!"
                label: "Keyword"
            }

            Row{

                spacing: Theme.paddingLarge

                Button{
                    text:"Reset"
                    onClicked:
                    {
                        key.text="";
                        city.text="";
                    }
                }

                Button  {
                    text:"Search"
                    onClicked: pageStack.push(Qt.resolvedUrl("SecondPage.qml"),
                                              { request:"http://api.eventful.com/rest/events/search?app_key=TMm7MhHVtCw6KStb&keyword="+ key.text +"&location="+
                                                        city.text +"&date="+ time +"&sort_order="+ sorting +"&page_size="+ number +"&within="+ range +"&=units=km"})
                }


            }

            Component {
                id: optionsPage
                Dialog {
                    canAccept: true
                    acceptDestination: page
                    acceptDestinationAction: PageStackAction.Pop

                    Flickable {
                        // ComboBox requires a flickable ancestor
                        width: parent.width
                        height: parent.height
                        interactive: false

                        Column {
                            width: parent.width
                            DialogHeader {
                                acceptText: "Accept"
                            }

                            ComboBox {
                                id: period
                                width: page.width
                                label: "Date"
                                currentIndex: 0
                                menu: ContextMenu {
                                    MenuItem { text: "Future" }
                                    MenuItem { text: "Next week" }
                                    MenuItem { text: "This week" }
                                    MenuItem { text: "Today" }
                                    MenuItem { text: "Last Week" }
                                    MenuItem { text: "Past" }
                                    MenuItem { text: "All" }

                                }
                            }
                            ComboBox {
                                id: sort
                                width: page.width
                                label: "Sort order"
                                currentIndex: 0
                                menu: ContextMenu {
                                    MenuItem { text: "Relevance" }
                                    MenuItem { text: "Popularity" }
                                    MenuItem { text: "Date" }
                                }
                            }
                            Slider {
                                id:rangeslider
                                value: range
                                minimumValue:1
                                maximumValue:100
                                stepSize: 1
                                width: parent.width
                                valueText: value.toFixed(0)
                                label: "Search in location's area (in km)"
                            }
                            Slider {
                                id:numberslider
                                value: range
                                minimumValue:1
                                maximumValue:100
                                stepSize: 1
                                width: parent.width
                                valueText: value.toFixed(0)
                                label: "Number of results"
                            }
                        }
                    }
                    onAccepted: {
                        time=period.value;
                        sorting=sort.value;
                        range=Math.round(rangeslider.value);
                        number=Math.round(numberslider.value);
                    }


                }
            }
        }
    }
}

