/*
  Copyright (C) 2013 Jolla Ltd.
  Contact: Thomas Perl <thomas.perl@jollamobile.com>
  All rights reserved.

  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0
import QtQuick.XmlListModel 2.0


Page {
    id: page
    property string request:""

    XmlListModel {
        id: events
        source: request
        query: "/search/events/event"

        XmlRole {
            name: "id"
            query: "@id/string()"
        }
        XmlRole {
            name: "url"
            query: "url/string()"
        }
        XmlRole {
            name: "title"
            query: "title/string()"
        }
        XmlRole {
            name: "start_time"
            query: "start_time/string()"
        }
        XmlRole {
            name: "stop_time"
            query: "stop_time/string()"
        }
        XmlRole {
            name: "venue"
            query: "venue_name/string()"
        }
        XmlRole {
            name: "address"
            query: "venue_address/string()"
        }
        XmlRole {
            name: "city"
            query: "city_name/string()"
        }
        XmlRole {
            name: "country"
            query: "country_name/string()"
        }
        XmlRole {
            name: "image"
            query: "image/thumb/url/string()"
        }
        XmlRole {
            name: "imageM"
            query: "image/medium/url/string()"
        }
        XmlRole {
            name: "description"
            query: "description/string()"
        }
        XmlRole {
                    name: "performers"
                    query: "performers/performer/name/string()"
                }
    }

    SilicaListView {
        id: listView
        model: events
        anchors.fill: parent
        spacing: Theme.paddingLarge

        header: PageHeader {
            title: "Search Results"
        }

        delegate: ListItem {

            Row{

                height: (info+label).height
                spacing: Theme.paddingLarge

                Column {

                    id: column
                    height: (info+label).height

                    Label {
                        id: label
                        text: model.title
                        width: 350
                        x: Theme.paddingLarge
                        horizontalAlignment: Text.AlignLeft
                        truncationMode: TruncationMode.Fade
                        color: Theme.primaryColor                        
                    }

                    Label{
                        id:info
                        width: 400
                        height: text.height                        
                        text: model.start_time+ ", " +model.city
                        color: Theme.secondaryColor
                        font.family: Theme.fontFamily
                        font.pixelSize: Theme.fontSizeExtraSmall
                        truncationMode: TruncationMode.Fade
                        x: Theme.paddingLarge
                    }
                }

                Image {
                            height: Theme.itemSizeSmall
                            width: Theme.itemSizeSmall
                            source: model.imageM
                            horizontalAlignment :Image.AlignRight
                            visible: (model.imageM.length>0)
                            verticalAlignment :Theme.paddingSmall
                }

                Image {
                            height: Theme.itemSizeSmall
                            width: Theme.itemSizeSmall
                            source: "http://s2.postimg.org/u2uty7jmh/stars.png"
                            horizontalAlignment :Image.AlignRight
                            visible: !(model.imageM.length>0)
                            verticalAlignment :Image.AlignHCenter
                }
            }

            height : 100        //height of one row

            onClicked: pageStack.push(Qt.resolvedUrl("ThirdPage.qml"),{ d_title:events.get(index).title,d_id:events.get(index).id,
                                          d_start_time:events.get(index).start_time,d_venue:events.get(index).venue,
                                          d_city:events.get(index).city,d_country:events.get(index).country,
                                          d_image:events.get(index).image,d_description:events.get(index).description,
                                          d_performers:events.get(index).performers,d_stop_time:events.get(index).stop_time,
                                          d_address:events.get(index).address,d_imageM:events.get(index).imageM,
                                          d_url:events.get(index).url,

                                      })        
        }

        VerticalScrollDecorator {}
    }
}





