/*
  Copyright (C) 2013 Jolla Ltd.
  Contact: Thomas Perl <thomas.perl@jollamobile.com>
  All rights reserved.

  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0
import QtQuick.XmlListModel 2.0


Page {

    id: page
    property string d_id:""
    property string d_title:""
    property string d_description:""
    property string d_start_time:""
    property string d_stop_time:""
    property string d_venue:""
    property string d_address:""
    property string d_city:""
    property string d_country:""
    property string d_image:""
    property string d_imageM:""
    property string d_performers:""
    property string d_url:""

    SilicaFlickable {
            anchors.fill: parent
            contentHeight: thirdcolumn.height
            contentWidth: parent.width

        VerticalScrollDecorator {}

        Column{

            id: thirdcolumn
            spacing: Theme.paddingLarge
            width: page.width

            PageHeader{
                title: "Event"
            }

            SectionHeader {
                text: "Title"
            }

            Row {
                TextArea {
                    readOnly: true
                    width: 350
                    height:text.height
                    text: d_title
                    color: Theme.primaryColor
                    font.weight : Font.Bold
                    font.family :Theme.fontFamily
                    font.italic: false
                    font.strikeout : false
                    font.underline : false
                    //font.capitalization : Font.SmallCaps
                    horizontalAlignment :TextEdit.AlignRight
                }

                Image {
                            height: Theme.itemSizeMedium
                            width: Theme.itemSizeMedium
                            source: d_imageM
                            horizontalAlignment :Image.AlignRight
                            visible: (d_imageM.length>0)
                }

                Image {
                            height: Theme.itemSizeLarge
                            width: Theme.itemSizeMedium
                            source: "http://s2.postimg.org/u2uty7jmh/stars.png"
                            horizontalAlignment :Image.AlignRight
                            visible: !(d_imageM.length>0)
                }
            }

            SectionHeader {
                text: "Time"
            }

            Column {

                TextArea {
                    readOnly: true
                    width: 550
                    height:text.height
                    text: "Start time:  "+d_start_time+"
Stop time:  "+d_stop_time
                }
            }

            SectionHeader {
                text: "Address"
            }

            Column {
                TextArea {
                    readOnly: true
                    width: 550
                    height:text.height
                    text: d_venue+"
"+d_address+"
"+d_city+ ", "+d_country
                }
            }

            SectionHeader {
                text: "Description"
                visible: (d_description.length>0)
            }

            TextArea {
                visible: (d_description.length>0)
                readOnly: true
                width: 550
                height:text.height;
                Component.onCompleted: {
               _editor.textFormat= TextEdit.RichText
                }
                horizontalAlignment :TextEdit.AlignJustify
                text: d_description

            }


            SectionHeader {
                text: "Performers"
                visible: (d_performers.length>0)
            }

            Column {
                TextArea {
                    visible: (d_performers.length>0)
                    readOnly: true
                    width: 550
                    height:text.height
                    text: d_performers
                }

                SectionHeader {
                    text: "Url"
                    visible: (d_url.length>0)
                }

                TextArea{
                    height:text.height
                    readOnly: true
                    width: 550                    
                    color: Text.color
                    text: " <a href=\""+d_url+"\">Link</a>"
                    Component.onCompleted: {
                   _editor.textFormat= TextEdit.RichText
                    }
                    onClicked: {
                          Qt.openUrlExternally(d_url)
                        console.log(d_url)
                        }
                }
            }
        }
    }
}





